using System.ComponentModel;
using System.Data;
using System.Windows.Forms;

namespace TestDgv
{
    public partial class Form1 : Form
    {
        public List<Espece> Especes = [];
        public List<Elevage> Elevages = [];

        public Form1()
        {
            InitializeComponent();

            this.SuspendLayout();

            LoadData();

            FillGrid1();
            FillGrid2();

            txt1.DataBindings.Add(new Binding("Text", Elevages[2], "Nom"));

            this.ResumeLayout();
        }

        private void LoadData()
        {
            Especes.Add(new(1, "Cheval"));
            Especes.Add(new(2, "Poule"));
            Especes.Add(new(3, "Vache"));

            Elevages.Add(new(1, "Pr fleuri", "2"));
            Elevages.Add(new(2, "Champ vert", "1"));
            Elevages.Add(new(3, "Moulin dor", "3"));
        }

        private void FillGrid1()
        {
            dgv1.AutoGenerateColumns = false;

            DataGridViewTextBoxColumn colCode = new()
            {
                DataPropertyName = "Code",
                ValueType = typeof(int),
            };
            dgv1.Columns.Add(colCode);

            DataGridViewTextBoxColumn colNom = new()
            {
                DataPropertyName = "Nom",
                ValueType = typeof(string),
            };
            dgv1.Columns.Add(colNom);

            DataGridViewComboBoxColumn colEspece = new()
            {
                DataPropertyName = "Espece",
                ValueType = typeof(string),
                DataSource = Especes,
                DisplayMember = "Nom",
                ValueMember = "StringCode",
            };
            dgv1.Columns.Add(colEspece);
            
            foreach (Elevage elevage in Elevages)
            {
                int lineNumber = dgv1.Rows.Add();
                dgv1.Rows[lineNumber].Cells[0].Value = elevage.Code;
                dgv1.Rows[lineNumber].Cells[1].Value = elevage.Nom;
                dgv1.Rows[lineNumber].Cells[2].Value = elevage.Espece;
            }
        }

        private void FillGrid2()
        {
            dgv2.AutoGenerateColumns = false;

            DataGridViewTextBoxColumn colCode = new()
            {
                DataPropertyName = "Code",
                ValueType = typeof(int),
            };
            dgv2.Columns.Add(colCode);

            DataGridViewTextBoxColumn colNom = new()
            {
                DataPropertyName = "Nom",
                ValueType = typeof(string),
            };
            dgv2.Columns.Add(colNom);

            DataGridViewComboBoxColumn colEspece = new()
            {
                DataPropertyName = "Espece",
                ValueType = typeof(string),
                DataSource = Especes,
                DisplayMember = "Nom",
                ValueMember = "StringCode",
            };
            dgv2.Columns.Add(colEspece);
            dgv2.DataSource = Elevages;
        }
    }

    public class Espece
    {
        public int Code { get; set; }
        public string StringCode {
            get
            {
                return Code.ToString();
            }
        }
        public string Nom { get; set; }

        public Espece(int code, string nom)
        {
            Code = code;
            Nom = nom;
        }
    }

    public class Elevage
    {
        public int Code { get; set; }
        public string Nom { get; set; }
        public string Espece { get; set; }

        public Elevage(int code, string nom, string espece)
        {
            Code = code;
            Nom = nom;
            Espece = espece;
        }
    }
}